@@ -5,7 +5,7 @@ import re
 from QonsoExtractor import QonsoExtractor
 from PyQt4 import QtWebKit, QtCore
 from PyQt4.QtNetwork import QNetworkRequest
-from DebugLog import DebugLog
+from DebugLog import DebugLog, DebugFile
 
 class QonsoExtractorBouygues(QonsoExtractor):
    def __init__(self):
@@ -20,9 +20,8 @@ class QonsoExtractorBouygues(QonsoExtractor):
 
    def Authenticate(self, idCorrelation):
       DebugLog("QonsoExtractorBouygues::Authenticate")
-      
       self.SetStatus('INFO', 'Authentification...')
-      self.progress = 66
+      self.SetProgressRange(10,20)
 
       request = self.PrepareRequest()
       request.setUrl( QtCore.QUrl(self.urlAuth+idCorrelation) ) 
@@ -91,7 +90,9 @@ class QonsoExtractorBouygues(QonsoExtractor):
          self.manager.get(request)
       
    def CheckForErrors(self, html):
-      r = re.compile('<div class="erreur">(.+?)</div>', re.DOTALL)
+      DebugLog("QonsoExtractorBouygues::CheckForErrors")
+      DebugFile(html)
+      r = re.compile('<div class="erreur">(.+?)</div>')
       res = r.search(html)
                
       if res:
@@ -112,27 +113,36 @@ class QonsoExtractorBouygues(QonsoExtractor):
       if self.CheckForErrors(html):
          return
       
+      self.SetProgress(10, 100)
       # Date de la dernière communication
       date = ""
-      res = re.search('DetailConsoDateConso">(\d{1,2}/\d{1,2}/\d{2,4})<', html)
+      res = re.search('DetailConsoDateConso".*?>(\d{1,2}/\d{1,2}/\d{2,4})<', html)
       if res:
          date = res.group(1)
+      DebugLog("date=%s"%date)
 
+      self.SetProgress(20, 100)
       # Heure de la dernière communication
       time = ""
-      res = re.search('DetailConsoHeureConso">(\d{1,2}h\d{1,2})<', html)
+      res = re.search('DetailConsoHeureConso".*?>(\d{1,2}h\d{1,2})<', html)
       if res:
          time = res.group(1)
+      DebugLog("time=%s"%time)
 
       if date and time:
          self.model.lastTime = "Ma consommation au "+date + " &agrave; " + time
 
+      self.SetProgress(30, 100)
       # Date de la prochaine facture
-      res = re.search('dateEmissionFacture">(\d{1,2}/\d{1,2}/\d{2,4})<', html)
+      res = re.search('dateEmissionFacture".*?>(\d{1,2}/\d{1,2}/\d{2,4})<', html)
       if res:
          date = res.group(1)
+         DebugLog("date f=%s"%date)
          self.model.facture = "Prochaine facture : "+date+" au soir"
+      else:
+         DebugLog("date f pas trouve")
 
+      self.SetProgress(40, 100)
       # Conso Voix
       DebugLog("_______________________________________________\nConso voix")
       DebugLog("-----------------------------------------------\n")
@@ -143,6 +153,7 @@ class QonsoExtractorBouygues(QonsoExtractor):
          self.model.SetConsoVoixMax( res.group(2) )
          self.model.SetConsoVoix( "0" )
       
+      self.SetProgress(50, 100)
       res = re.search("votre [Ff]orfait (.+) de %smin.+vous avez consomm.+?%s" %(self.hmReS, self.hmReS), html)
       if res:
          DebugLog(res.groups())
@@ -150,11 +161,23 @@ class QonsoExtractorBouygues(QonsoExtractor):
          self.model.SetConsoVoixMax( res.group(2) )
          self.model.SetConsoVoix( res.group(3) )
          
-      # if self.model.forfait.find("Neo")>-1:
-         # self.model.dataMax = 500
-      # if self.model.forfait.find("Evasio")>-1:
-         # self.model.dataMax = 500
+      # Conso Data
+      DebugLog("_______________________________________________\nConso data")
+      DebugLog("-----------------------------------------------\n")
+      res = re.search('class="gv2_detailsConso_typo_orange_gras".*?>([\d,]+?)&nbsp;Mo', html)
+      if res:
+         DebugLog(res.groups())
+         self.model.SetConsoData( res.group(1) )
+         
+      res = re.search('Lorsque votre débit aura atteint&nbsp;(\d+).*?Mo', html)
+      if res:
+         DebugLog(res.groups())
+         self.model.SetConsoDataMax( res.group(1) )
+      else:
+         if self.model.forfait.find("Neo")>-1 or self.model.forfait.find("Evasio")>-1:
+            self.model.SetConsoDataMax("500")
 
+      self.SetProgress(60, 100)
       # Conso Voix Supplémentaire
       if self.model.forfait.find("Evasio")>-1:
          DebugLog("_______________________________________________\nConso voix Supplémentaire")
@@ -165,6 +188,7 @@ class QonsoExtractorBouygues(QonsoExtractor):
             self.model.SetConsoVoixSupp( res.group(1) )
             self.model.SetConsoVoixSuppMax( self.model.GetConsoVoixMax('str') )
 
+      self.SetProgress(70, 100)
       # SMS
       DebugLog("_______________________________________________\nConso SMS")
       DebugLog("-----------------------------------------------\n")
@@ -180,6 +204,7 @@ class QonsoExtractorBouygues(QonsoExtractor):
             self.model.SetConsoSMS( res.group(2) )
             self.model.SetConsoSMSMax( res.group(1) )
 
+      self.SetProgress(80, 100)
       # Bonus SMS
       DebugLog("_______________________________________________\nBonus SMS")
       DebugLog("-----------------------------------------------\n")
@@ -204,6 +229,7 @@ class QonsoExtractorBouygues(QonsoExtractor):
                self.model.SetConsoSMSSupp( res.group(2) )
                self.model.SetConsoSMSSuppMax( res.group(1) )
          
+      self.SetProgress(90, 100)
       # Report de minutes
       DebugLog("_______________________________________________\nReport de minutes")
       DebugLog("-----------------------------------------------\n")
@@ -219,6 +245,7 @@ class QonsoExtractorBouygues(QonsoExtractor):
                self.model.SetReport( res.group(1) )
                DebugLog("report = "+res.group(1))
 
+      self.SetProgress(99, 100)
       # Hors forfait
       DebugLog("_______________________________________________\nHors forfait")
       DebugLog("-----------------------------------------------\n")
