@@ -10,7 +10,6 @@ from DebugLog import DebugLog
 class QonsoExtractorSFR(QonsoExtractor):
    def __init__(self):
       DebugLog("QonsoExtractorSFR::init")
-
       QonsoExtractor.__init__(self)
 
       # URL de la page d'info conso
@@ -27,13 +26,21 @@ class QonsoExtractorSFR(QonsoExtractor):
    def Authenticate(self):
       DebugLog("QonsoExtractorSFR::Authenticate")
       self.SetStatus('INFO', 'Authentification...')
-      self.progress = 66
+      self.SetProgressRange(33,66)
 
       params = QtCore.QUrl()
       # Mettre ici les paramètres du formulaire (login, password, champs cachés)
       params.addQueryItem("username", self.login)
       params.addQueryItem("password", self.password)
       params.addQueryItem("loginTicket", self.ticket)
+      params.addQueryItem("identifier", '')
+
+      # cookies = self.manager.cookieJar().cookiesForUrl(QtCore.QUrl("http://"+self.hostname))
+      # DebugLog("cookies %d"%len(cookies))
+      # for cookie in cookies:
+         # DebugLog(cookie)
+         # if cookie.name()=="JSESSIONID":
+             # DebugLog(cookie)
 
       self.PostRequest(params)
 
