@@ -27,12 +27,12 @@ class QonsoExtractorVirginMobile(QonsoExtractor):
    def Authenticate(self):
       DebugLog("QonsoExtractorVirginMobile::Authenticate")
       self.SetStatus('INFO', 'Authentification...')
+      self.SetProgressRange(33,66)
 
       params = QtCore.QUrl()
       # Mettre ici les paramètres du formulaire (login, password, champs cachés)
       params.addQueryItem("msisdn", self.login)
       params.addQueryItem("password", self.password)
-      params.addQueryItem("internal", "W")
       
       request = QNetworkRequest()
       request.setUrl( QtCore.QUrl( self.urlAuth%(self.login, self.password) ) ) 
