@@ -12,7 +12,7 @@ from DebugLog import DebugLog
 class QonsoView(QtGui.QMainWindow):
    def __init__(self, argv, parent=None):
       QtGui.QMainWindow.__init__(self, parent)
-      
+
       DebugLog("QonsoView::Init")
       self.offline = os.environ.has_key('OFFLINE')
       self.setMaximumSize(QtCore.QSize(800, 480))
@@ -40,10 +40,10 @@ class QonsoView(QtGui.QMainWindow):
       self.model = QonsoModel()
       self.extractor = None
       self.credentialsOk = False
-      
+
       if not self.config.GetLogin() or not self.config.GetPassword() or not self.config.GetOperator():
          self.config.AskForCredentials()
-      
+
       self.layoutsOK = False
       self.centralWidget = QtGui.QWidget()
 
@@ -51,7 +51,7 @@ class QonsoView(QtGui.QMainWindow):
       self.centralWidget.setLayout(self.vbox)
       self.setCentralWidget( self.centralWidget )
       self.firstDisplay = True
-      
+
       self.credentialsOk = True
       self.CreateAppLayouts()
 
@@ -65,7 +65,7 @@ class QonsoView(QtGui.QMainWindow):
          f.close()
          self.CreateConsoLayouts()
          self.extractor.authentication = 'Done'
-      else: 
+      else:
          self.CreateExtractor( self.config.GetOperator() )
          self.extractor.SetOffline(False)
          self.extractor.InitAuthenticate()
@@ -77,7 +77,13 @@ class QonsoView(QtGui.QMainWindow):
       self.extractor.SetLogin(self.config.GetLogin())
       self.extractor.SetPassword(self.config.GetPassword())
       self.extractor.SetModel(self.model)
-      
+      self.connect(self.extractor, QtCore.SIGNAL("progress"), self.UpdateBar)
+      self.connect(self.extractor, QtCore.SIGNAL('extracted'), self.UpdateConsoText, QtCore.Qt.QueuedConnection)
+
+   def UpdateBar(self):
+      DebugLog("QonsoView::UpdateBar(%f)"%self.extractor.GetProgress())
+      self.statusLabel[1].setValue( self.extractor.GetProgress() )
+
    def Settings(self):
       self.config.AskForCredentials()
       if self.config.updated:
@@ -86,7 +92,7 @@ class QonsoView(QtGui.QMainWindow):
          self.credentialsOk = True
          self.layoutsOK = False
          self.extractor = None
-      
+
    def Reset(self):
       DebugLog("QonsoView::Reset")
       self.model = QonsoModel()
@@ -97,18 +103,18 @@ class QonsoView(QtGui.QMainWindow):
          if not self.boxes.has_key(label):
             del data
             del wid
-            
+
          else:
             if data:
                DebugLog("removing data "+label)
                self.boxes[label].removeWidget(data)
                del data
-               
+
             if wid:
                DebugLog("removing wid "+label)
                self.boxes[label].removeWidget(wid)
                del wid
-               
+
             self.vbox.removeItem(self.boxes[label])
             del self.boxes[label]
 
@@ -116,8 +122,8 @@ class QonsoView(QtGui.QMainWindow):
       self.boxes.clear()
       self.statusLabel[0].show()
       self.statusLabel[1].show()
-      
-   def CreateAppLayouts(self):      
+
+   def CreateAppLayouts(self):
       DebugLog("QonsoView::CreateAppLayouts")
       exit = QtGui.QAction(u'Paramètres', self)
       exit.setShortcut('Ctrl+O')
@@ -126,7 +132,7 @@ class QonsoView(QtGui.QMainWindow):
       update = QtGui.QAction(u'Rafraichir', self)
       update.setShortcut('Ctrl+R')
       self.connect(update, QtCore.SIGNAL('triggered()'), self.UpdateConso)
-      
+
       about = QtGui.QAction(u'A propos...', self)
       self.connect(about, QtCore.SIGNAL('triggered()'), self.About)
 
@@ -139,36 +145,36 @@ class QonsoView(QtGui.QMainWindow):
       self.statusBox, label, progress = self.CreateLayout('status', None, True)
       self.statusLabel = label, progress
       self.statusLabel[1].setShowRules(False)
-      
+
       self.vbox.addLayout(self.statusBox)
       self.vbox.setSpacing(0)
       self.vbox.setMargin(0)
-   
+
    def CreateConsoLayouts(self):
       DebugLog("QonsoView::CreateConsoLayouts")
-      
+
       iconPath = '/opt/qonso/icons'
       if not os.path.exists(iconPath):
          iconPath = 'icons'
-      
+
       self.CreateAndAddLayout('compte', None)
       self.CreateAndAddLayout('voix', os.path.join(iconPath, 'voix.png'), self.model.GetConsoVoixMax('int')!=None )
-      
+
       if self.model.GetConsoVoixSupp('str'):
          self.CreateAndAddLayout('voixSupp', os.path.join(iconPath, 'voixsupp.png'), True)
 
       if self.model.GetConsoSMSMax() != '0':
          self.CreateAndAddLayout('sms', os.path.join(iconPath, 'sms.png') )
-      
+
       if self.model.GetConsoSMSSupp():
          self.CreateAndAddLayout('smsSupp', os.path.join(iconPath, 'smssupp.png') )
-      
-      if self.model.GetConsoDataMax()>0:
+
+      if self.model.GetConsoDataMax('int')>0:
          self.CreateAndAddLayout('data', os.path.join(iconPath, 'data.png'), True)
 
       if self.model.GetConsoHorsForfait()!=None:
          self.CreateAndAddLayout('hforfait', os.path.join(iconPath, 'hforfait.png'), False)
-         
+
       if self.model.GetDateProchaineFacture()!=None:
          self.CreateAndAddLayout('facture', None)
 
@@ -184,11 +190,11 @@ class QonsoView(QtGui.QMainWindow):
 
    def CreateLayout(self, name, icon, progress=False):
       DebugLog("QonsoView::CreateLayout(%s, %s, %d)" % (name, str(icon), progress) )
-      
+
       box = QtGui.QHBoxLayout()
       box.setSpacing(0)
       box.setMargin(0)
-      
+
       if icon:
          pixicon = QtGui.QPixmap(icon).scaled(64,64)
          label = QtGui.QLabel()
@@ -208,14 +214,13 @@ class QonsoView(QtGui.QMainWindow):
       data.setMaximumSize(QtCore.QSize(800, 800))
       data.setStyleSheet("background: #fff;")
       data.setAlignment(QtCore.Qt.AlignCenter)
-      
+
       vbox = QtGui.QVBoxLayout()
       vbox.addWidget(data)
       wid = None
-      
+
       if progress:
-         # wid = QtGui.QProgressBar()
-         # wid.setTextVisible(False)
+#         wid = QtGui.QProgressBar()
          wid = WProgress(self)
          wid.setStyleSheet("background: #fff; margin: 0; padding: 10px; border-bottom: 1px solid #269CCA")
          vbox.addWidget(wid)
@@ -224,13 +229,13 @@ class QonsoView(QtGui.QMainWindow):
          data.setStyleSheet("background: #fff; margin: 0; padding: 5px; border-bottom: 1px solid #269CCA")
 
       box.addLayout(vbox)
-         
+
       return box, data, wid
 
    def UpdateConsoText(self):
       if not self.extractor:
-         return 
-      
+         return
+
       status, context = self.extractor.GetStatus()
 
       if status=='ERROR':
@@ -240,13 +245,13 @@ class QonsoView(QtGui.QMainWindow):
       elif status=='DONE':
          self.statusLabel[0].hide()
          self.statusLabel[1].hide()
-         
+
       else:
          self.SetText(self.statusLabel[0], "#269CCA", 16, context)
-         self.statusLabel[1].setValue( self.extractor.GetProgress() )
+         # self.statusLabel[1].setValue( self.extractor.GetProgress() )
          #time.sleep(1)
          #self.update()
-         
+
       if self.labels.has_key('compte') and self.model.GetLastTime():
          self.SetText(self.labels['compte'][0], "#269CCA", 16, self.model.GetLastTime()+
                       "<br/>"+self.model.GetReport('str'))
@@ -271,29 +276,33 @@ class QonsoView(QtGui.QMainWindow):
          self.SetText(self.labels['smsSupp'][0], "#EB5F18", 20, self.model.GetConsoSMSSupp() +"/" + self.model.GetConsoSMSSuppMax())
 
       if self.labels.has_key('data'):
-         dataMax = self.model.GetConsoDataMax()
-         data = self.model.GetConsoData()
-         self.SetText(self.labels['data'][0], "#EB5F18", 20, str(data)+" / "+str(dataMax)+"Mo")
+         dataMax = self.model.GetConsoDataMax('int')
+         dataMaxstr = self.model.GetConsoDataMax('str')
+         data = self.model.GetConsoData('int')
+         datastr = self.model.GetConsoData('str')
+         self.SetText(self.labels['data'][0], "#EB5F18", 20, "%s/%sMo"%(datastr, dataMaxstr))
          self.labels['data'][1].setRange(0, dataMax)
          self.labels['data'][1].setValue( data )
-      
+
       if self.labels.has_key('hforfait'):
          self.SetText(self.labels['hforfait'][0], "#EB5F18", 20, self.model.GetConsoHorsForfait() )
-         
+
       if self.labels.has_key('facture'):
          self.SetText(self.labels['facture'][0], "#269CCA", 16, self.model.GetDateProchaineFacture())
 
+      self.update()
+
    def SetText(self, label, color, size, text):
       label.setText('<span style="color: %s; font-weight: bold; font-size: %dpt">%s</span>' % (color, size, text))
-   
+
    def UpdateConso(self):
       DebugLog("QonsoView::UpdateConso")
       self.extractor.UpdateConso()
-      
+
    def About(self):
       QtGui.QMessageBox.about(self, "A propos", u'Qonso\nDéveloppé par Gérald Fauvelle\nhttp://projects.forum.nokia.com/Qonso')
       return
-   
+
    def paintEvent(self, event):
       if self.firstDisplay:
          if self.credentialsOk and (not self.extractor or not self.extractor.authentication):
@@ -301,11 +310,11 @@ class QonsoView(QtGui.QMainWindow):
          elif not self.layoutsOK:
             if self.extractor and self.extractor.datasExtracted:
                self.CreateConsoLayouts()
-               self.extractor.datasExtracted = False 
+               self.extractor.datasExtracted = False
       self.firstDisplay = True
       self.UpdateConsoText()
       event.accept()
-      
+
    def closeEvent(self, event):
       self.config.WriteConfig()
       event.accept()
