@@ -46,9 +46,11 @@ class WProgress(QtGui.QLabel):
       x0 = int(size.width()*0.15)
       w = size.width()-2*x0
       
-      if self.currentValue<self.value:
-         self.currentValue = (self.currentValue + 0.02*self.value)
-         time.sleep(0.01)
+      self.currentValue = self.value
+      
+      # if self.currentValue<self.value:
+         # self.currentValue = (self.currentValue + 0.02*self.value)
+         # time.sleep(0.01)
 
       if self.max-self.min>0:
          pcVal = float(self.currentValue-self.min)/float(self.max-self.min)
@@ -80,7 +82,7 @@ class WProgress(QtGui.QLabel):
                paint.drawText(x0+i-fw/2, self.ytop-self.height/2, str(self.num[j]))
                j = j + 1
 
-      if self.currentValue<self.value:
-         self.update()
+      # if self.currentValue<self.value:
+         # self.update()
          
       paint.end()
